@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: StatisticsHandler.py 13182 2021-08-04 07:20:14Z Casey $
+# $Id: StatisticsHandler.py 13183 2021-08-04 07:34:23Z Casey $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Casey $
-# $Date: 2021-08-04 15:20:14 +0800 (Wed, 04 Aug 2021) $
-# $Revision: 13182 $
+# $Date: 2021-08-04 15:34:23 +0800 (Wed, 04 Aug 2021) $
+# $Revision: 13183 $
 
 from datetime import timedelta, datetime
 
@@ -37,17 +37,17 @@ STATUS_NAMES = STATUS_DICT.values()
 STATUS_CODE = STATUS_DICT.keys()
 
 _STATUS_NAMES = [
-    STATUS_DICT[ContactMailingStatus.SENT],
-    STATUS_DICT[ContactMailingStatus.ERROR],
-    STATUS_DICT[ContactMailingStatus.INVALID],
-    STATUS_DICT[ContactMailingStatus.OPENED],
-    STATUS_DICT[ContactMailingStatus.OPENED_ON_SITE],
-    STATUS_DICT[ContactMailingStatus.LINK_OPENED],
-    STATUS_DICT[ContactMailingStatus.UNSUBSCRIPTION],
-    STATUS_DICT[ContactMailingStatus.BOUNCED],
-    STATUS_DICT[ContactMailingStatus.COMPLAINT],
-    STATUS_DICT[ContactMailingStatus.REJECTED],
-    STATUS_DICT[ContactMailingStatus.SENT_TEST]
+    str(STATUS_DICT[ContactMailingStatus.SENT]),
+    str(STATUS_DICT[ContactMailingStatus.ERROR]),
+    str(STATUS_DICT[ContactMailingStatus.INVALID]),
+    str(STATUS_DICT[ContactMailingStatus.OPENED]),
+    str(STATUS_DICT[ContactMailingStatus.OPENED_ON_SITE]),
+    str(STATUS_DICT[ContactMailingStatus.LINK_OPENED]),
+    str(STATUS_DICT[ContactMailingStatus.UNSUBSCRIPTION]),
+    str(STATUS_DICT[ContactMailingStatus.BOUNCED]),
+    str(STATUS_DICT[ContactMailingStatus.COMPLAINT]),
+    str(STATUS_DICT[ContactMailingStatus.REJECTED]),
+    str(STATUS_DICT[ContactMailingStatus.SENT_TEST])
 ]
 
 from django.db import connection
